%global namedreltag .RELEASE
%global namedversion %{version}%{?namedreltag}
%global oname spring-data-commons

Name:          springframework-data-commons
Version:       1.8.4
Release:       12%{?dist}
Summary:       Interfaces between relational and non-relational data stores
License:       ASL 2.0
URL:           http://projects.spring.io/spring-data/
# Newer release require springframework >= 4.0.7.RELEASE
Source0:       https://github.com/spring-projects/spring-data-commons/archive/%{namedversion}.tar.gz


BuildRequires: maven-local
BuildRequires: mvn(com.google.guava:guava)
BuildRequires: mvn(com.fasterxml.jackson.core:jackson-databind)
BuildRequires: mvn(com.mysema.querydsl:querydsl-apt)
BuildRequires: mvn(com.mysema.querydsl:querydsl-core)
BuildRequires: mvn(javax.annotation:jsr250-api)
BuildRequires: mvn(javax.ejb:ejb-api)
BuildRequires: mvn(javax.enterprise:cdi-api)
BuildRequires: mvn(javax.servlet:javax.servlet-api)
BuildRequires: mvn(joda-time:joda-time)
BuildRequires: mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires: mvn(org.springframework:spring-beans)
BuildRequires: mvn(org.springframework:spring-context)
BuildRequires: mvn(org.springframework:spring-core)
BuildRequires: mvn(org.springframework:spring-expression)
BuildRequires: mvn(org.springframework:spring-oxm)
BuildRequires: mvn(org.springframework:spring-tx)
BuildRequires: mvn(org.springframework:spring-web)
BuildRequires: mvn(org.springframework:spring-webmvc)
BuildRequires: mvn(org.springframework.hateoas:spring-hateoas)

%if 0
# Test deps
# https://bugzilla.redhat.com/show_bug.cgi?id=1217162
BuildRequires: mvn(com.mysema.maven:apt-maven-plugin)
BuildRequires: mvn(com.sun.xml.bind:jaxb-impl)
BuildRequires: mvn(javax.el:javax.el-api)
BuildRequires: mvn(org.apache.openwebbeans.test:cditest-owb)
BuildRequires: mvn(org.codehaus.groovy:groovy-all:1.8.6)
BuildRequires: mvn(xmlunit:xmlunit)
%endif

BuildArch:     noarch

%description
Spring Data Commons is part of the umbrella Spring Data project that
provides shared infrastructure across the Spring Data projects. Most
importantly at the moment it contains technology neutral repository
interfaces as well as a meta-data model for persisting Java classes.

Features:
° Powerful Repository and custom object-mapping abstractions
° Support for cross-store persistence
° Dynamic query generation from query method names
° Implementation domain base classes providing basic properties
° Support for transparent auditing (created, last changed)
° Possibility to integrate custom repository code
° Easy Spring integration with custom name-space

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{oname}-%{namedversion}

cp -p src/main/resources/*.txt .
sed -i 's/\r//' *.txt

# https://github.com/spring-projects/spring-data-build
%pom_remove_parent
# Remove unavailable plugins
%pom_remove_plugin :apt-maven-plugin
%pom_remove_plugin :wagon-maven-plugin
# Remove unwanted plugin
%pom_remove_plugin :maven-assembly-plugin

# Set dependecies version (available in parent pom)
%pom_xpath_set "pom:dependency[pom:groupId='com.fasterxml.jackson.core']/pom:version" 2.5.0
%pom_xpath_set "pom:dependency[pom:groupId='javax.enterprise']/pom:version" 1.1
%pom_xpath_set "pom:dependency[pom:groupId='joda-time']/pom:version" 2.3
%pom_xpath_set "pom:dependency[pom:groupId='org.apache.openwebbeans.test']/pom:version" 1.2.0
%pom_xpath_set "pom:dependency[pom:groupId='com.mysema.querydsl']/pom:version" 3.6.4

# Force EL 3.0 apis
%pom_xpath_set "pom:dependency[pom:groupId='javax.el']/pom:artifactId" javax.el-api
%pom_xpath_set "pom:dependency[pom:groupId='javax.el']/pom:version" 3.0.0
# Force servlet 3.1 apis
%pom_xpath_set "pom:dependency[pom:groupId='javax.servlet']/pom:artifactId" javax.servlet-api
%pom_xpath_set "pom:dependency[pom:groupId='javax.servlet']/pom:version" 3.1.0

# Use jvm apis (java.util.Optional)
%pom_remove_dep org.springframework.data.build:spring-data-java8-stub

# Add OSGi support
%pom_xpath_inject "pom:project" "<packaging>bundle</packaging>"
%pom_add_plugin org.apache.felix:maven-bundle-plugin . '
<extensions>true</extensions>
<configuration>
  <instructions>
    <Bundle-SymbolicName>org.springframework.data.core</Bundle-SymbolicName>
    <Bundle-Name>${project.name}</Bundle-Name>
    <Bundle-Vendor>Pivotal Software, Inc.</Bundle-Vendor>
    <Bundle-Version>${project.version}</Bundle-Version>
  </instructions>
</configuration>
<executions>
  <execution>
    <id>bundle-manifest</id>
    <phase>process-classes</phase>
    <goals>
      <goal>manifest</goal>
    </goals>
  </execution>
</executions>'

%mvn_file : %{oname}

%build

# Unavailable test deps
%mvn_build -f -- -Dproject.build.sourceEncoding=UTF-8

%install
%mvn_install

%files -f .mfiles
%doc changelog.txt readme.*
%license license.txt notice.txt

%files javadoc -f .mfiles-javadoc
%license license.txt notice.txt

%changelog
* Sun Feb 03 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.4-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.4-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.4-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.4-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.4-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Jun 20 2016 gil cattaneo <puntogil@libero.it> 1.8.4-7
- add missing build requires: maven-plugin-bundle

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Jan 30 2016 gil cattaneo <puntogil@libero.it> - 1.8.4-5
- rebuilt

* Fri Jun 19 2015 gil cattaneo <puntogil@libero.it> 1.8.4-4
- use querydsl 3.6.4

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jun 02 2015 gil cattaneo <puntogil@libero.it> 1.8.4-2
- fix summary field
- cleanup spec file
- fix some rpmlint problems

* Fri Jan 02 2015 gil cattaneo <puntogil@libero.it> 1.8.4-1
- initial rpm
